@@ -44,7 +44,9 @@ def get_embeddings_for_tokens(dataset, cdb, context_type='medium', special_token
                 id2tkn[len(embeddings)] = tkn
                 id2type[len(embeddings)] = token_type
                 tkn2id[tkn] = len(embeddings)
-                embeddings.append(unitvec(vec))
+
+                vec = unitvec(vec) if normalize else vec
+                embeddings.append(vec)
 
     # Add special tokens
     for tkn in special_tokens:
